(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    105748,       1873]
NotebookOptionsPosition[    103656,       1833]
NotebookOutlinePosition[    104150,       1851]
CellTagsIndexPosition[    104107,       1848]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Chapter 10, Section 10.3.2, Figure 10.8", "Section",ExpressionUUID->"c70cf993-ca78-4b07-a19a-cdb98b93d561"],

Cell[TextData[{
 "We start by using Eq.(10.19) to define an approximation for the radius, ",
 StyleBox["r", "Input"],
 ", as a function of the longitude, ",
 StyleBox["\[Theta]c", "Input"],
 ", in the corotating frame."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"a4913c4c-99d0-4ac0-b64f-c5c2cc6d486e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"r", "[", 
   RowBox[{"a_", ",", "e_", ",", " ", "m_", ",", " ", "\[Theta]c_"}], "]"}], 
  " ", ":=", " ", 
  RowBox[{"a", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"e", "*", 
      RowBox[{"Cos", "[", 
       RowBox[{"m", "*", "\[Theta]c"}], "]"}]}]}], ")"}]}]}]], "Input",
 CellLabel->"In[1]:=",ExpressionUUID->"8d5e9068-848f-4744-b177-c997cef89f5c"],

Cell[TextData[{
 "Now define a function, ",
 StyleBox["StreamLine", "Input"],
 ", that will plot the streamline path of mode ",
 StyleBox["m", "Input"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b4b1f8d0-656c-4148-90c4-8d014207c940"],

Cell[BoxData[
 RowBox[{
  RowBox[{"StreamLine", "[", "m_", "]"}], ":=", "\n", 
  RowBox[{"ParametricPlot", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"r", "[", 
        RowBox[{"1", ",", "0.2", ",", "m", ",", "\[Theta]c"}], "]"}], "*", 
       RowBox[{"Cos", "[", "\[Theta]c", "]"}]}], ",", 
      RowBox[{
       RowBox[{"r", "[", 
        RowBox[{"1", ",", "0.2", ",", "m", ",", "\[Theta]c"}], "]"}], "*", 
       RowBox[{"Sin", "[", "\[Theta]c", "]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Theta]c", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"AspectRatio", "->", "1"}], ",", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}]}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellLabel->"In[2]:=",ExpressionUUID->"84d95893-11f8-4da1-ac05-d0da5487afcc"],

Cell[TextData[{
 "Plot the streamline for ",
 StyleBox["m", "Input"],
 " = 0.  The result is a circle centred on the origin.  (See Fig.10.8a.)"
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"06c90901-a7a8-445c-9537-d84ad3d7d84c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StreamLine", "[", "0", "]"}]], "Input",
 CellLabel->"In[3]:=",ExpressionUUID->"ce31f9a0-53c9-4a5b-b533-db66f3b4779e"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJw1m3k0VY/Xh0WKkJBKCaFQaZCSol0RKUkRKVTKFEkhDQglc2TOkKnMIkNm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       "]]},
     Annotation[#, "Charting`Private`Tag$1296#1"]& ]}, {}},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "ScalingFunctions" -> 
    None},
  PlotRange->{{-1.5, 1.5}, {-1.5, 1.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8120135797338877`*^9},
 CellLabel->"Out[3]=",ExpressionUUID->"de1b92d5-4ac4-43ab-b3c8-f879c0c40008"]
}, Open  ]],

Cell[TextData[{
 "Plot the streamline for ",
 StyleBox["m", "Input"],
 " = 1.  The result is an ellipse (or displaced circle).  (See Fig.10.8b.)"
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"43a96e07-da25-42d3-a6c9-5747ed417972"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StreamLine", "[", "1", "]"}]], "Input",
 CellLabel->"In[4]:=",ExpressionUUID->"28d103d9-05ae-4c18-a15c-dde559abbb2d"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJw123k81N/3OPASWSJrCklSScqSbFlOEbKmSCQpIZGkPSoUSdllCUUR2bIV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       "]]},
     Annotation[#, "Charting`Private`Tag$1363#1"]& ]}, {}},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "ScalingFunctions" -> 
    None},
  PlotRange->{{-1.5, 1.5}, {-1.5, 1.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.812013579801149*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"2c095ecd-1c0c-41fe-b0e7-e64da3c76b4a"]
}, Open  ]],

Cell[TextData[{
 "Plot the streamline for ",
 StyleBox["m", "Input"],
 " = 2.  The result is a centred ellipse or \"two-lobed figure\".  (See \
Fig.10.8c.)"
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"02a460ba-58f7-4100-9867-a4da4dafcbe2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StreamLine", "[", "2", "]"}]], "Input",
 CellLabel->"In[5]:=",ExpressionUUID->"9caf7fcb-603b-4da9-8fc8-d0df390ff67e"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJws3Hc8Vf//APAopJSk0iIjFUnS1HplpKSikIaMBkqoxCeVUUb2HhkJ2QmR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       "]]},
     Annotation[#, "Charting`Private`Tag$1389#1"]& ]}, {}},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "ScalingFunctions" -> 
    None},
  PlotRange->{{-1.5, 1.5}, {-1.5, 1.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.812013579868103*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"a3287fe0-d550-4d6e-bd3f-b45820c36f71"]
}, Open  ]],

Cell[TextData[{
 "Plot the streamline for ",
 StyleBox["m", "Input"],
 " = 7.  The result is seven-lobed figure.  (See Fig.10.8d.)"
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b0d2a4c6-7d38-4d46-af94-88fe2d8ba62a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StreamLine", "[", "7", "]"}]], "Input",
 CellLabel->"In[6]:=",ExpressionUUID->"d34a3336-9673-4591-bd62-1099fa116c2a"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJwseXc81e/7P0IlldUihCgrokXqklESqZCRkCRFIiLyNhNCGWU0jELIzCzj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       "]]},
     Annotation[#, "Charting`Private`Tag$1415#1"]& ]}, {}},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "ScalingFunctions" -> 
    None},
  PlotRange->{{-1.5, 1.5}, {-1.5, 1.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.812013579950405*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"8eaad87c-b14e-4c10-9d22-40b8dbf94cc8"]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{914, 365},
WindowMargins->{{29, Automatic}, {Automatic, 291}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"12.1 for Mac OS X x86 (64-bit) (June 19, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"ed2ec8e8-ebb7-422d-9436-19076ce26f79"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 113, 0, 67, "Section",ExpressionUUID->"c70cf993-ca78-4b07-a19a-cdb98b93d561"],
Cell[674, 22, 341, 9, 72, "Text",ExpressionUUID->"a4913c4c-99d0-4ac0-b64f-c5c2cc6d486e"],
Cell[1018, 33, 398, 11, 30, "Input",ExpressionUUID->"8d5e9068-848f-4744-b177-c997cef89f5c"],
Cell[1419, 46, 279, 9, 53, "Text",ExpressionUUID->"b4b1f8d0-656c-4148-90c4-8d014207c940"],
Cell[1701, 57, 1074, 29, 94, "Input",ExpressionUUID->"84d95893-11f8-4da1-ac05-d0da5487afcc"],
Cell[2778, 88, 265, 7, 53, "Text",ExpressionUUID->"06c90901-a7a8-445c-9537-d84ad3d7d84c"],
Cell[CellGroupData[{
Cell[3068, 99, 141, 2, 30, "Input",ExpressionUUID->"ce31f9a0-53c9-4a5b-b533-db66f3b4779e"],
Cell[3212, 103, 19322, 329, 373, "Output",ExpressionUUID->"de1b92d5-4ac4-43ab-b3c8-f879c0c40008"]
}, Open  ]],
Cell[22549, 435, 267, 7, 53, "Text",ExpressionUUID->"43a96e07-da25-42d3-a6c9-5747ed417972"],
Cell[CellGroupData[{
Cell[22841, 446, 141, 2, 30, "Input",ExpressionUUID->"28d103d9-05ae-4c18-a15c-dde559abbb2d"],
Cell[22985, 450, 19214, 327, 373, "Output",ExpressionUUID->"2c095ecd-1c0c-41fe-b0e7-e64da3c76b4a"]
}, Open  ]],
Cell[42214, 780, 278, 8, 53, "Text",ExpressionUUID->"02a460ba-58f7-4100-9867-a4da4dafcbe2"],
Cell[CellGroupData[{
Cell[42517, 792, 141, 2, 30, "Input",ExpressionUUID->"9caf7fcb-603b-4da9-8fc8-d0df390ff67e"],
Cell[42661, 796, 23874, 403, 373, "Output",ExpressionUUID->"a3287fe0-d550-4d6e-bd3f-b45820c36f71"]
}, Open  ]],
Cell[66550, 1202, 253, 7, 53, "Text",ExpressionUUID->"b0d2a4c6-7d38-4d46-af94-88fe2d8ba62a"],
Cell[CellGroupData[{
Cell[66828, 1213, 141, 2, 30, "Input",ExpressionUUID->"d34a3336-9673-4591-bd62-1099fa116c2a"],
Cell[66972, 1217, 36668, 613, 396, "Output",ExpressionUUID->"8eaad87c-b14e-4c10-9d22-40b8dbf94cc8"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

